





******

Bravo!  You have received a Medical Diploma in "sovereignty" from   
the Orbital Convergence University International Air and Water Embassy of the Tangerine Planet.  

You are now officially certified to include "sovereignty" in your practice.

******


# sovereignty

## taps (OCHLV)
### taps.season_3.super_hero_trend
	
## stats (options)
### stats.aggregate_break_even
### stats.aggregate_PC_ratio


## clouds
### clouds.Coinbase.API.products.candles